@@ -64,13 +64,8 @@ class JsonEncoder( json.JSONEncoder ) :
 def json_encode( data ) :
     return json.dumps( data , cls = JsonEncoder )
 
-
-
-
-
 #####################################################################
 
-
 # FIXME TODO aaarrggghhh!!!
 def time_getisoformat( ) :
 
@@ -78,7 +73,6 @@ def time_getisoformat( ) :
 
     return( dt )
 
-
 #>>> now = datetime.now()
 #>>> now
 #datetime.datetime(2021, 11, 29, 11, 55, 27, 172480)
@@ -89,21 +83,28 @@ def time_getisoformat( ) :
 #datetime.datetime(2021, 11, 29, 11, 56, 21, 316679, tzinfo=tzlocal())
 #>>> now.tzname()
 
+def pickle_load( datakey , fromtmp = False ) :
 
+    fn = "local_" + datakey + ".pkl"
+
+    if(fromtmp):
+        fn="/tmp/"+fn
 
-def pickle_load( fn ) :
     if( os.path.isfile( fn ) ) :
-        s_log.write_msg( "FOUND " + fn )
         with open( fn , "rb" ) as f :
             return( pickle.load( f ) )
     else :
         return None
         
-def pickle_save( datakey , data ) :
-    f = open( "local_" + datakey + ".pkl" , "wb" )
-    pickle.dump( run_response , f )
+def pickle_save( datakey , data , mvtotmp = False ) :
+    fn = "local_" + datakey + ".pkl"
+    f = open( fn , "wb" )
+    pickle.dump( data , f )
     f.close( )
 
+    if( mvtotmp ) :
+        os.rename( fn , "/tmp/" + fn )
+
 
  
 def pathnotallowed( p ) :
